==> nmail-php-patch-2.3.1-to-2.4.0.tgz: nmail/include/global_var.default.php <==
<? if ( !defined("_INCLUDED_GLOBAL") ) exit;		// [Security]Allow_url_fopen = On ?>
<?


###############################################################################
# Global Variables
###############################################################################


	// user - Ʈ (κ )
		#$G_SYS[ADMIN_EMAIL] = "postmaster@";
		$G_SYS[ADMIN_EMAIL_NAME] = "";
		#$G_SYS[SITE_NAME] = "";		// ex) нڸƳ 
		#$G_SYS[SITE_OWNER] = "нڸƳ";		// ex) нڸƳ
		#$G_SYS[SITE_TITLE] = "Nmail Linux/Unix 2.0 for PHP - http://passkorea.net";


	// user - 
		#$G_SYS[MBR_ID_DENY] = array('root', 'admin', 'superadmin', 'demo', 'mail', 'nmail', 'webmail', 'master', 'webmaster', 'postmaster', 'abuse', 'service', 'help');		// ȸԽ  ID .(  Ʈ ʿ .)
		$G_SYS[SMTP_ADDR] = "127.0.0.1";		// smtp server address.  default: 127.0.0.1
		$G_SYS[SMTP_PORT] = 25;		// smtp server port.  default: 25
		#$UPLOAD_MAX_SIZE = 10485760;	// ε ѿ뷮.  ex) 1024 * 1024 * 1 = 1MB(1048576)
		#$G_SYS[UPLOAD_MAIL_MAX_SIZE] = 10485760;	//  ÷ ѿ뷮.  ⺻ - 10MB(10485760)
		#$G_SYS[VIRUS_SCAN] = false;		// ̷  ˻翩.(ɼ ġǾ ־ .)
		$G_SYS['WEBEDITOR'] = 'OPEN';		// OPEN - openWYSIWYG, FCK - FCKeditor, GM - GMeditor( ġؾ)


	//   /   ϴ .  (⺻ false)
		//    Ͱ ۵ ʰ,  ڿ  .
		$G_SYS['SPAM_CHECK_SKIP'] = false;

		
	// Ų 
		$NSKIN['ver'] = '2.0';		// Ų .

	
	//  
		$G_SYS['DRAFT_SAVE_AUTO_TIME'] = 120;		//  'ӽúԿ ڵ ϱ'.(⺻ 120, 2)


	// ϵ 
		$G_SYS['WEBHARD_NAME'] = 'ϵ';		// ϵ Ī(ũ, Ϲڽ ...)


	// system - DB
		include_once("include/global_db.php");


	// system - Session
		$G_SYS[SESSION_LIFETIME] = 0;		//  ȿð.  ʴ.
		$G_SYS[SESSION_PATH] = "/";		//  ȿ.
		$G_SYS[SESSION_DOMAIN] = "";		//   쿡 θ Է.  ex) .domain.com => www.domain.com, club.domain.com
		$G_SYS[SESSION_GC_MAXLIFETIME] = 7200;		//   Žð.		ex) 1ð => 3600, 2ð => 7200


	// system - ڿ
		$G_SYS[PAGE_ROOT] = dirname(dirname(__FILE__));
		// [2005-08-04] Ʈ,  丮 URL ٷ ϴ ҽ  .
		if ($G_SYS[PAGE_ROOT] == dirname(realpath($_SERVER['SCRIPT_FILENAME'])))
		{
			$G_SYS[URL_ROOT] = dirname($_SERVER["PHP_SELF"]);
		} else
		{
			$G_SYS[URL_ROOT] = dirname(dirname($_SERVER["PHP_SELF"]));
		}	// if()
		if ( ($G_SYS[URL_ROOT] == "/") || ($G_SYS[URL_ROOT] == "\\") ) $G_SYS[URL_ROOT] = "";
		$G_SYS[HTTP_URL_ROOT] = "http://" . $_SERVER["HTTP_HOST"] . $G_SYS[URL_ROOT];

		$G_SYS[MAIL_DOMAIN_DEFAULT_SIZE] = 3145728;		// Ͽ뷮 Ҵ緮.  kbyte.  ex) 3145728 => 3G
		$G_SYS[MAIL_DEFAULT_SIZE] = 30720;		// ⺻ Ͽ뷮.  kbyte.  ex) 30720 => 30MB
		$G_SYS[MBR_DEFAULT_COUNT] = 100;		//  Ҵ.  .

		// [2006-09-05] Windows
		if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN')
		{
			$G_SYS[MAIL_ROOT] = "C:\NmailPHP\MailRoot\domains";
			$G_SYS[PAGE_ROOT] = str_replace('\\', '/', $G_SYS[PAGE_ROOT]);
			$G_SYS[MAIL_ROOT] = str_replace('\\', '/', $G_SYS[MAIL_ROOT]);
		} else 
		{
			$G_SYS[MAIL_ROOT] = "/var/MailRoot/domains";			
		}	// if()

		$G_SYS[WEBLOGS_DIR] = dirname($G_SYS[PAGE_ROOT])."/weblogs";
		$G_SYS[FILTERTEMP_DIR] = dirname($G_SYS[PAGE_ROOT])."/filtertemp";
		$G_SYS[MAILTO] = "mail_write.php?mf_to=";
		// ȸ йȣ ȣȭ  .  ȸ Ե Ŀ  ϸ ȵ˴ϴ.
		$G_SYS[PWD_ENC] = "MD5";		// MD5, MYSQL (⺻ MD5)
		$G_SYS[CHARSET] = "euc-kr";
		$G_SYS[LC_CTYPE] = "ko_KR.eucKR";
		$G_SYS['MBR_GROUP_MAX'] = 20;		// ϳ 丮/̺  ȸ.   (⺻ 20, ϶ 999999 Է)
		$G_SYS['BOARD_QUOTA_DEFAULT'] = 2097152;		// κ ⺻ ڷ Ҵ緮.  ⺻ - 2GB(2097152)
		$G_SYS['CHARSETS_ISUSE'] = false;		//  ڵ ÿ (ڵ  )

		// [2007-01-17]б ϴ ±׸   ֽϴ.
		// '±|±'̾ ϸ ߰ ߸ ڰ    ߻մϴ.
		$G_SYS['MAIL_READ_DEL_TAGS'] = 'html|body|iframe|link|meta|object|embed|form|base';

		$G_SYS[PRE_FIX] = "nmail_";

		$UPLOAD_ROOT = $G_SYS[PAGE_ROOT] . "/data";
		$UPLOAD_DIR[CONFIG] = "config";
		$UPLOAD_DIR[MEMBER] = "member";
		$UPLOAD_DIR[BOARD] = "board";
		$UPLOAD_ISHIDDEN = true;		// upload  ϵ url  .(  ̹ ĳ  ʾ    .)
		$CHMOD_CHANGE = 0707;		// upload  ۹̼.  ex) -rwx---rwx
		$CHMOD_CHANGE_STR = "707";		// upload  ۹̼.  ex) -rwx---rwx
		$UPLOAD[FILTER_EXT][IMG] = array("jpg", "jpeg", "gif", "png", "pcx", "bmp", "tif", "tiff");
		$UPLOAD[FILTER_EXT][FLASH] = array("swf");

		/*
			debug info

			VIEW : ȭ ϴܿ ٷ .
			HIDDEN : html ҽ ϴܿ ּ· .

		*/
		#$G_SYS['DEBUG_TYPE'] = 'VIEW';
		$G_SYS['DEBUG_TYPE'] = 'HIDDEN';

		// [2005-09-07]
		#$G_SYS['DEBUG_QUERY'] = 'VIEW';
		$G_SYS['DEBUG_QUERY'] = 'HIDDEN';

		// [2005-12-11]
		$G_SYS['DEBUG_QUERY_OVER_TIME'] = 2;		//  ð(sec)     ⵵ .  ⺻ : 2sec.


###############################################################################


	// Level
		/* Level ex
			level : 0
			level_name : մ
			level_key : guest
		*/
		$G['LEVEL'] = array(
								"guest" => 0,
								"out" => 1,
								"wait" => 2,
								"user" => 3,
								"admin" => 7,
								"serveradmin" => 9
								);							

		$G['LEVEL_NAME'] = array(
								0 => "մ",
								1 => "Żȸ",
								2 => "Դ",
								3 => "ȸ",
								7 => "",
								9 => ""
								);


###############################################################################


	// Member
		$G_MB[DEFAULT_JOIN_LEVEL] = $G[LEVEL][wait];		// Խ ο .  ex) user -> 3 -> Ϲݰȸ
		$G_MB[DEFAULT_JOIN_LEVEL_BYADMIN] = $G[LEVEL][user];		// ڰ ȸ߰ ο .  ex) user -> 3 -> Ϲݰȸ
		#$G_MB[ISCHECK_JUMIN_DUPLICATE] = true;		// ȸԽ ֹεϹȣ ߺüũ  .  ex) true -> ߺüũ, false -> ߺüũ.
		$G_MB[ISCHECK_JUMIN_DUPLICATE] = false;		// ȸԽ ֹεϹȣ ߺüũ  .  ex) true -> ߺüũ, false -> ߺüũ.
		#$G_MB[ID_MIN_LENGTH] = 2;		// ̵ ּұ .  ⺻ 2̻.

		// ܺȸ  뿩. (Y, N)
		$G_SYS['SSO_ISUSE'] = 'N';

		// ܺȸ ó   ŰԴϴ.(ϰ ܺȸ⿡  ؾ .)
		// ܺο  ʵ Ͻð ġ ݵ Ʒ   ڿ(32ڳ) ٲٽñ ٶϴ.
		$G_SYS['SSO_KEY'] = '';

		// ܺȸ //Ż ũ.(ܺȸ ش ũ    ֽϴ.)
		$G_SYS['SSO_JOIN_URL'] = '';		//  Ʈ ȸ ּ
		$G_SYS['SSO_JOIN_URL_TARGET'] = '';		//    Ÿ 
		$G_SYS['SSO_MODIFY_URL'] = '';		//  Ʈ ȸ ּ
		$G_SYS['SSO_MODIFY_URL_TARGET'] = '';		//    Ÿ 
		$G_SYS['SSO_OUT_URL'] = '';		//  Ʈ ȸŻ ּ
		$G_SYS['SSO_OUT_URL_TARGET'] = '';		//    Ÿ 
		$G_SYS['SSO_PASSWDFIND_URL'] = '';		//  Ʈ йȣã ּ
		$G_SYS['SSO_PASSWDFIND_URL_TARGET'] = '';		//    Ÿ 
		$G_SYS['SSO_NOT_URL_MSG'] = "ܺȸ ϵ Ǿϴ.\\n\\n ȸ  Ͻ  ϴ.";
		$G_SYS['SSO_JOIN_LEVEL'] = $G[LEVEL][wait];		// ܺȸ⿡ Խ ο .   'Ϲȸ' 'wait' 'user' .

		// ٸ Ʈ frame   ΰ ߺǴ  ϱ .
		$G_SYS['SSO_SKIN_TOP_LOGO_HIDDEN'] = false;		// ex) true -> ΰ , false -> ΰ .
		$G_SYS['SSO_SKIN_TOP_MENU_HIDDEN'] = false;		// ex) true -> ܸ޴ , false -> ܸ޴ .


	// 
		// з(ִ 255) - 迭 պκ ڴ ߰ Ǹ ȵǸ,  ǹǷ ϸ ȵ˴ϴ.
			$G_SYS['DI_KIND'] = array(
				1=>'', 
				2=>'', 
				3=>'', 
				4=>'', 
				5=>'ް', 
				6=>'Ÿ'
				);
			$G_SYS['DI_KIND_KEY'] = array_keys($G_SYS['DI_KIND']);
			$G_SYS['DI_KIND_VAL'] = array_values($G_SYS['DI_KIND']);
		// Ǯ
			$G_SYS['DI_REPEAT'] = array(
				'N'=>'', 
				'Y'=>'ų()', 
				'L'=>'ų() '
				);
		// 
			$G_SYS['DAYOFWEEK'] = array("", "", "ȭ", "", "", "", "");


	//  ڵ з
		$G_SYS['AUTO_FILTER_MAX'] = 20;		// δ ִ 20  .


	//  Ⱓ
		$G_SYS['MB_SAVEDAY'] = array(
			0=>'Ѿ',
			5=>'5',
			10=>'10',
			15=>'15',
			20=>'20',
			25=>'25',
			30=>'30',
			40=>'40',
			50=>'50',
			60=>'60'
			);
		$G_SYS['MB_SAVEDAY_ID'] = array('trash', 'spam');

	// [2006-07-25] ⺻  - Ը  , ̹  ǥü
		$G_SYS['M_CFG_NEW_CNT'] = array(
			3=>'3',
			5=>'5',
			7=>'7',
			10=>'10',
			15=>'15'
			);		

	// [2006-07-25] ⺻  - б 
		$G_SYS['M_CFG_MAIL_LIST_CNT'] = array(
			10=>'10',
			15=>'15',
			20=>'20',
			30=>'30',
			50=>'50',
			75=>'75',
			100=>'100'
			);		

	// [2006-11-01]  ڵ - ڵ տ   .
	$G_SYS['AUTOREPLY_SUBJECT_PREFIX'] = "[ ڵ] ";


###############################################################################


	// Board
		$G_BOARD[S_KIND] = array(
										"b_subject"=>"",
										"b_memo"=>"",
										"b_name"=>"ۼ",
										"ALL"=>"ü"
										);

		$G_BOARD[S_KIND_ADMIN] = array(
										"mu.mu_name"=>"̸",
										"ba.ba_isuse_link"=>"ũ",
										"ba.ba_isuse_file"=>"",
										"ba.ba_isuse_comment"=>"",
										"ba.ba_isuse_reply"=>"亯",
										"ba.ba_regdate"=>"",
										"ba.ba_last_modifydate"=>""
										);

		// οԽù ؽð(ʴ)
		$G_BOARD[NEW_TIME] = 259200;		// 60*60*24*3 = 259200 (3̳)

		//    ڸ(  Ǹ,  Ͻÿ   )
		$G_BOARD[NOTICE_LENGTH] = 500;		// 500 byte


###############################################################################


	// General

		$G[ISSIGN] = array(
								"Y" => "",
								"N" => ""
								);

		$G[ISUSE] = array(
								"Y" => "",
								"N" => ""
								);

		$G[ISNOTNULL] = array(
								"Y" => "ʼԷ",
								"N" => "ϹԷ"
								);

		$G[ISLIST] = array(
								"Y" => "ǥ",
								"N" => "ǥþ"
								);

		$G[ISSYSTEM] = array(
								"Y" => "ý׸",
								"N" => "Ϲ׸"
								);

		$G[ISVOTE] = array(
								"Y" => "õ",
								"N" => "õ"
								);

		$G[ISPOSSIBLE] = array(
								"Y" => "",
								"N" => "Ұ"
								);

		$G[BIRTHDAY_EAST] = array(
								"S" => "",
								"L" => ""
								);

		$G[ISREMAIL] = array(
								"Y" => "",
								"N" => ""
								);


		$G[ISUSE_REPLY_MAIL] = array(
								"Y" => "亯 ",
								"N" => "亯 "
								);

		$G[ISSEND] = array(
								"N" => "߼۴",
								"Y" => "߼ۿϷ"
								);

		$G[SEX] = array(
								"M" => "",
								"F" => ""
								);

		$G[ISMARRY] = array(
								"Y" => "ȥ",
								"N" => "ȥ"
								);

		$G[JOB] = array(
								"б ",
								"л",
								"()",
								"繫",
								"",
								"/Ǹ",
								"",
								" ",
								"Ƿ",
								"/",
								"",
								"",
								"/",
								"",
								"ֺ",
								"ڿ",
								"//",
								"",
								"/",
								"񿵸ü",
								"",
								"",
								"Ÿ"
								);

		$G[HTML] = array(
										"N"=>"TEXT",
										"Y"=>"HTML",
										"M"=>"HTML + <BR>"
										);

		$G[AND_OR] = array(
								"AND",
								"OR"
								);


###############################################################################


?>

==> nmail-php-patch-2.5.2-to-2.6.1.tgz: nmail/include/global_var.default.php <==
<? if ( !defined("_INCLUDED_GLOBAL") ) exit;		// [Security]Allow_url_fopen = On ?>
<?


###############################################################################
# Global Variables
###############################################################################


	// user - Ʈ (κ )
		#$G_SYS[ADMIN_EMAIL] = "postmaster@";
		$G_SYS[ADMIN_EMAIL_NAME] = "";
		#$G_SYS[SITE_NAME] = "";		// ex) нڸƳ 
		#$G_SYS[SITE_OWNER] = "нڸƳ";		// ex) нڸƳ
		#$G_SYS[SITE_TITLE] = "Nmail Linux/Unix 2.0 for PHP - http://passkorea.net";


	// user - 
		#$G_SYS[MBR_ID_DENY] = array('root', 'admin', 'superadmin', 'demo', 'mail', 'nmail', 'webmail', 'master', 'webmaster', 'postmaster', 'abuse', 'service', 'help');		// ȸԽ  ID .(  Ʈ ʿ .)
		$G_SYS[SMTP_ADDR] = "127.0.0.1";		// smtp server address.  default: 127.0.0.1
		$G_SYS[SMTP_PORT] = 25;		// smtp server port.  default: 25
		#$UPLOAD_MAX_SIZE = 10485760;	// ε ѿ뷮.  ex) 1024 * 1024 * 1 = 1MB(1048576)
		#$G_SYS[UPLOAD_MAIL_MAX_SIZE] = 10485760;	//  ÷ ѿ뷮.  ⺻ - 10MB(10485760)
		#$G_SYS[VIRUS_SCAN] = false;		// ̷  ˻翩.(ɼ ġǾ ־ .)
		$G_SYS['WEBEDITOR'] = 'TINYMCE';		// TINYMCE - TinyMCE, OPEN - openWYSIWYG


	//   /   ϴ .  (⺻ false)
		//    Ͱ ۵ ʰ,  ڿ  .
		$G_SYS['SPAM_CHECK_SKIP'] = false;

		
	// Ų 
		$NSKIN['ver'] = '2.0';		// Ų .

	
	//  
		$G_SYS['DRAFT_SAVE_AUTO_TIME'] = 120;		//  'ӽúԿ ڵ ϱ'.(⺻ 120, 2)


	// ϵ 
		$G_SYS['WEBHARD_NAME'] = 'ϵ';		// ϵ Ī(ũ, Ϲڽ ...)


	// system - DB
		include_once("include/global_db.php");


	// system - Session
		$G_SYS[SESSION_LIFETIME] = 0;		//  ȿð.  ʴ.
		$G_SYS[SESSION_PATH] = "/";		//  ȿ.
		$G_SYS[SESSION_DOMAIN] = "";		//   쿡 θ Է.  ex) .domain.com => www.domain.com, club.domain.com
		$G_SYS[SESSION_GC_MAXLIFETIME] = 7200;		//   Žð.		ex) 1ð => 3600, 2ð => 7200


	// system - ڿ
		$G_SYS[PAGE_ROOT] = dirname(dirname(__FILE__));
		// [2005-08-04] Ʈ,  丮 URL ٷ ϴ ҽ  .
		if ($G_SYS[PAGE_ROOT] == dirname(realpath($_SERVER['SCRIPT_FILENAME'])))
		{
			$G_SYS[URL_ROOT] = dirname($_SERVER["PHP_SELF"]);
		} else
		{
			$G_SYS[URL_ROOT] = dirname(dirname($_SERVER["PHP_SELF"]));
		}	// if()
		if ( ($G_SYS[URL_ROOT] == "/") || ($G_SYS[URL_ROOT] == "\\") ) $G_SYS[URL_ROOT] = "";
		$G_SYS[HTTP_URL_ROOT] = "http://" . $_SERVER["HTTP_HOST"] . $G_SYS[URL_ROOT];

		$G_SYS[MAIL_DOMAIN_DEFAULT_SIZE] = 10485760;		// Ͽ뷮 Ҵ緮.  kbyte.  ex) 10485760 => 10G
		$G_SYS[MAIL_DEFAULT_SIZE] = 102400;		// ⺻ Ͽ뷮.  kbyte.  ex) 102400 => 100MB
		$G_SYS[MBR_DEFAULT_COUNT] = 100;		//  Ҵ.  .

		// [2006-09-05] Windows
		if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN')
		{
			$G_SYS[MAIL_ROOT] = "C:\NmailPHP\MailRoot\domains";
			$G_SYS[PAGE_ROOT] = str_replace('\\', '/', $G_SYS[PAGE_ROOT]);
			$G_SYS[MAIL_ROOT] = str_replace('\\', '/', $G_SYS[MAIL_ROOT]);
		} else 
		{
			$G_SYS[MAIL_ROOT] = "/var/MailRoot/domains";			
		}	// if()

		$G_SYS[WEBLOGS_DIR] = dirname($G_SYS[PAGE_ROOT])."/weblogs";
		$G_SYS[FILTERTEMP_DIR] = dirname($G_SYS[PAGE_ROOT])."/filtertemp";
		$G_SYS[MAILTO] = "mail_write.php?mf_to=";
		// ȸ йȣ ȣȭ  .  ȸ Ե Ŀ  ϸ ȵ˴ϴ.
		$G_SYS[PWD_ENC] = "MD5";		// MD5, MYSQL (⺻ MD5)
		$G_SYS[CHARSET] = "euc-kr";
		$G_SYS[LC_CTYPE] = "ko_KR.eucKR";
		$G_SYS['MBR_GROUP_MAX'] = 20;		// ϳ 丮/̺  ȸ.   (⺻ 20, ϶ 999999 Է)
		$G_SYS['BOARD_QUOTA_DEFAULT'] = 2097152;		// κ ⺻ Խ ÷ Ҵ緮.  ⺻ - 2GB(2097152)
		$G_SYS['CHARSETS_ISUSE'] = false;		//  ڵ ÿ (ڵ  )

		// [2007-01-17]б ϴ ±׸   ֽϴ.
		// '±|±'̾ ϸ ߰ ߸ ڰ    ߻մϴ.
		$G_SYS['MAIL_READ_DEL_TAGS'] = 'html|body|iframe|link|meta|object|embed|form|base';

		$G_SYS[PRE_FIX] = "nmail_";

		$UPLOAD_ROOT = $G_SYS[PAGE_ROOT] . "/data";
		$UPLOAD_DIR[CONFIG] = "config";
		$UPLOAD_DIR[MEMBER] = "member";
		$UPLOAD_DIR[BOARD] = "board";
		$UPLOAD_ISHIDDEN = true;		// upload  ϵ url  .(  ̹ ĳ  ʾ    .)
		$CHMOD_CHANGE = 0707;		// upload  ۹̼.  ex) -rwx---rwx
		$CHMOD_CHANGE_STR = "707";		// upload  ۹̼.  ex) -rwx---rwx
		$UPLOAD[FILTER_EXT][IMG] = array("jpg", "jpeg", "gif", "png", "pcx", "bmp", "tif", "tiff");
		$UPLOAD[FILTER_EXT][FLASH] = array("swf");

		/*
			debug info

			VIEW : ȭ ϴܿ ٷ .
			HIDDEN : html ҽ ϴܿ ּ· .

		*/
		#$G_SYS['DEBUG_TYPE'] = 'VIEW';
		$G_SYS['DEBUG_TYPE'] = 'HIDDEN';

		// [2005-09-07]
		#$G_SYS['DEBUG_QUERY'] = 'VIEW';
		$G_SYS['DEBUG_QUERY'] = 'HIDDEN';

		// [2005-12-11]
		$G_SYS['DEBUG_QUERY_OVER_TIME'] = 2;		//  ð(sec)     ⵵ .  ⺻ : 2sec.


###############################################################################


	// Level
		/* Level ex
			level : 0
			level_name : մ
			level_key : guest
		*/
		$G['LEVEL'] = array(
								"guest" => 0,
								"out" => 1,
								"wait" => 2,
								"user" => 3,
								"admin" => 7,
								"serveradmin" => 9
								);							

		$G['LEVEL_NAME'] = array(
								0 => "մ",
								1 => "Żȸ",
								2 => "Դ",
								3 => "ȸ",
								7 => "",
								9 => ""
								);


###############################################################################


	// Member
		$G_MB[DEFAULT_JOIN_LEVEL] = $G[LEVEL][wait];		// Խ ο .  ex) user -> 3 -> Ϲݰȸ
		$G_MB[DEFAULT_JOIN_LEVEL_BYADMIN] = $G[LEVEL][user];		// ڰ ȸ߰ ο .  ex) user -> 3 -> Ϲݰȸ
		#$G_MB[ISCHECK_JUMIN_DUPLICATE] = true;		// ȸԽ ֹεϹȣ ߺüũ  .  ex) true -> ߺüũ, false -> ߺüũ.
		$G_MB[ISCHECK_JUMIN_DUPLICATE] = false;		// ȸԽ ֹεϹȣ ߺüũ  .  ex) true -> ߺüũ, false -> ߺüũ.
		#$G_MB[ID_MIN_LENGTH] = 2;		// ̵ ּұ .  ⺻ 2̻.

		// ܺȸ  뿩. (Y, N)
		$G_SYS['SSO_ISUSE'] = 'N';

		// ܺȸ ó   ŰԴϴ.(ϰ ܺȸ⿡  ؾ .)
		// ܺο  ʵ Ͻð ġ ݵ Ʒ   ڿ(32ڳ) ٲٽñ ٶϴ.
		$G_SYS['SSO_KEY'] = '';

		// ܺȸ //Ż ũ.(ܺȸ ش ũ    ֽϴ.)
		$G_SYS['SSO_JOIN_URL'] = '';		//  Ʈ ȸ ּ
		$G_SYS['SSO_JOIN_URL_TARGET'] = '';		//    Ÿ 
		$G_SYS['SSO_MODIFY_URL'] = '';		//  Ʈ ȸ ּ
		$G_SYS['SSO_MODIFY_URL_TARGET'] = '';		//    Ÿ 
		$G_SYS['SSO_OUT_URL'] = '';		//  Ʈ ȸŻ ּ
		$G_SYS['SSO_OUT_URL_TARGET'] = '';		//    Ÿ 
		$G_SYS['SSO_PASSWDFIND_URL'] = '';		//  Ʈ йȣã ּ
		$G_SYS['SSO_PASSWDFIND_URL_TARGET'] = '';		//    Ÿ 
		$G_SYS['SSO_NOT_URL_MSG'] = "ܺȸ ϵ Ǿϴ.\\n\\n ȸ  Ͻ  ϴ.";
		$G_SYS['SSO_JOIN_LEVEL'] = $G[LEVEL][wait];		// ܺȸ⿡ Խ ο .   'Ϲȸ' 'wait' 'user' .

		// ٸ Ʈ frame   ΰ ߺǴ  ϱ .
		$G_SYS['SSO_SKIN_TOP_LOGO_HIDDEN'] = false;		// ex) true -> ΰ , false -> ΰ .
		$G_SYS['SSO_SKIN_TOP_MENU_HIDDEN'] = false;		// ex) true -> ܸ޴ , false -> ܸ޴ .


	// 
		// з(ִ 255) - 迭 պκ ڴ ߰ Ǹ ȵǸ,  ǹǷ ϸ ȵ˴ϴ.
			$G_SYS['DI_KIND'] = array(
				1=>'', 
				2=>'', 
				3=>'', 
				4=>'', 
				5=>'ް', 
				6=>'Ÿ'
				);
			$G_SYS['DI_KIND_KEY'] = array_keys($G_SYS['DI_KIND']);
			$G_SYS['DI_KIND_VAL'] = array_values($G_SYS['DI_KIND']);
		// Ǯ
			$G_SYS['DI_REPEAT'] = array(
				'N'=>'', 
				'Y'=>'ų()', 
				'L'=>'ų() '
				);
		// 
			$G_SYS['DAYOFWEEK'] = array("", "", "ȭ", "", "", "", "");


	//  ڵ з
		// [2011-03-29] ̵ ư ߰
		//$G_SYS['AUTO_FILTER_MAX'] = 20;		// δ ִ 20  .
		$G_SYS['AUTO_FILTER_MAX'] = 50;		// δ ִ 50  .


	//  Ⱓ
		$G_SYS['MB_SAVEDAY'] = array(
			0=>'Ѿ',
			5=>'5',
			10=>'10',
			15=>'15',
			20=>'20',
			25=>'25',
			30=>'30',
			40=>'40',
			50=>'50',
			60=>'60'
			);
		$G_SYS['MB_SAVEDAY_ID'] = array('trash', 'spam');

	// [2006-07-25] ⺻  - Ը  , ̹  ǥü
		$G_SYS['M_CFG_NEW_CNT'] = array(
			3=>'3',
			5=>'5',
			7=>'7',
			10=>'10',
			15=>'15'
			);		

	// [2006-07-25] ⺻  - б 
		$G_SYS['M_CFG_MAIL_LIST_CNT'] = array(
			10=>'10',
			15=>'15',
			20=>'20',
			30=>'30',
			50=>'50',
			75=>'75',
			100=>'100'
			);		

	// [2006-11-01]  ڵ - ڵ տ   .
	$G_SYS['AUTOREPLY_SUBJECT_PREFIX'] = "[ ڵ] ";


###############################################################################


	// Board
		$G_BOARD[S_KIND] = array(
										"b_subject"=>"",
										"b_memo"=>"",
										"b_name"=>"ۼ",
										"ALL"=>"ü"
										);

		$G_BOARD[S_KIND_ADMIN] = array(
										"mu.mu_name"=>"̸",
										"ba.ba_isuse_link"=>"ũ",
										"ba.ba_isuse_file"=>"",
										"ba.ba_isuse_comment"=>"",
										"ba.ba_isuse_reply"=>"亯",
										"ba.ba_regdate"=>"",
										"ba.ba_last_modifydate"=>""
										);

		// οԽù ؽð(ʴ)
		$G_BOARD[NEW_TIME] = 259200;		// 60*60*24*3 = 259200 (3̳)

		//    ڸ(  Ǹ,  Ͻÿ   )
		$G_BOARD[NOTICE_LENGTH] = 500;		// 500 byte


###############################################################################


	// General

		$G[ISSIGN] = array(
								"Y" => "",
								"N" => ""
								);

		$G[ISUSE] = array(
								"Y" => "",
								"N" => ""
								);

		$G[ISNOTNULL] = array(
								"Y" => "ʼԷ",
								"N" => "ϹԷ"
								);

		$G[ISLIST] = array(
								"Y" => "ǥ",
								"N" => "ǥþ"
								);

		$G[ISSYSTEM] = array(
								"Y" => "ý׸",
								"N" => "Ϲ׸"
								);

		$G[ISVOTE] = array(
								"Y" => "õ",
								"N" => "õ"
								);

		$G[ISPOSSIBLE] = array(
								"Y" => "",
								"N" => "Ұ"
								);

		$G[BIRTHDAY_EAST] = array(
								"S" => "",
								"L" => ""
								);

		$G[ISREMAIL] = array(
								"Y" => "",
								"N" => ""
								);


		$G[ISUSE_REPLY_MAIL] = array(
								"Y" => "亯 ",
								"N" => "亯 "
								);

		$G[ISSEND] = array(
								"N" => "߼۴",
								"Y" => "߼ۿϷ"
								);

		$G[SEX] = array(
								"M" => "",
								"F" => ""
								);

		$G[ISMARRY] = array(
								"Y" => "ȥ",
								"N" => "ȥ"
								);

		$G[JOB] = array(
								"б ",
								"л",
								"()",
								"繫",
								"",
								"/Ǹ",
								"",
								" ",
								"Ƿ",
								"/",
								"",
								"",
								"/",
								"",
								"ֺ",
								"ڿ",
								"//",
								"",
								"/",
								"񿵸ü",
								"",
								"",
								"Ÿ"
								);

		$G[HTML] = array(
										"N"=>"TEXT",
										"Y"=>"HTML",
										"M"=>"HTML + <BR>"
										);

		$G[AND_OR] = array(
								"AND",
								"OR"
								);


###############################################################################


?>
